==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/org_policy_policy/OrgPolicyPolicyDryRunSpecRules.java <==
package com.hashicorp.cdktf.providers.google.org_policy_policy;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:42.646Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.orgPolicyPolicy.OrgPolicyPolicyDryRunSpecRules")
@software.amazon.jsii.Jsii.Proxy(OrgPolicyPolicyDryRunSpecRules.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface OrgPolicyPolicyDryRunSpecRules extends software.amazon.jsii.JsiiSerializable {

    /**
     * Setting this to true means that all values are allowed.
     * <p>
     * This field can be set only in policies for list constraints.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#allow_all OrgPolicyPolicy#allow_all}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAllowAll() {
        return null;
    }

    /**
     * condition block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#condition OrgPolicyPolicy#condition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition getCondition() {
        return null;
    }

    /**
     * Setting this to true means that all values are denied.
     * <p>
     * This field can be set only in policies for list constraints.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#deny_all OrgPolicyPolicy#deny_all}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDenyAll() {
        return null;
    }

    /**
     * If <code>true</code>, then the policy is enforced.
     * <p>
     * If `false`, then any configuration is acceptable. This field can be set only in policies for boolean constraints.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#enforce OrgPolicyPolicy#enforce}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getEnforce() {
        return null;
    }

    /**
     * values block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#values OrgPolicyPolicy#values}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues getValues() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link OrgPolicyPolicyDryRunSpecRules}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link OrgPolicyPolicyDryRunSpecRules}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<OrgPolicyPolicyDryRunSpecRules> {
        java.lang.String allowAll;
        com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition condition;
        java.lang.String denyAll;
        java.lang.String enforce;
        com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues values;

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getAllowAll}
         * @param allowAll Setting this to true means that all values are allowed.
         *                 This field can be set only in policies for list constraints.
         *                 
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#allow_all OrgPolicyPolicy#allow_all}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowAll(java.lang.String allowAll) {
            this.allowAll = allowAll;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getCondition}
         * @param condition condition block.
         *                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#condition OrgPolicyPolicy#condition}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder condition(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition condition) {
            this.condition = condition;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getDenyAll}
         * @param denyAll Setting this to true means that all values are denied.
         *                This field can be set only in policies for list constraints.
         *                
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#deny_all OrgPolicyPolicy#deny_all}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder denyAll(java.lang.String denyAll) {
            this.denyAll = denyAll;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getEnforce}
         * @param enforce If <code>true</code>, then the policy is enforced.
         *                If `false`, then any configuration is acceptable. This field can be set only in policies for boolean constraints.
         *                
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#enforce OrgPolicyPolicy#enforce}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enforce(java.lang.String enforce) {
            this.enforce = enforce;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getValues}
         * @param values values block.
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/org_policy_policy#values OrgPolicyPolicy#values}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder values(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues values) {
            this.values = values;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link OrgPolicyPolicyDryRunSpecRules}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public OrgPolicyPolicyDryRunSpecRules build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link OrgPolicyPolicyDryRunSpecRules}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements OrgPolicyPolicyDryRunSpecRules {
        private final java.lang.String allowAll;
        private final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition condition;
        private final java.lang.String denyAll;
        private final java.lang.String enforce;
        private final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues values;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowAll = software.amazon.jsii.Kernel.get(this, "allowAll", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.condition = software.amazon.jsii.Kernel.get(this, "condition", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition.class));
            this.denyAll = software.amazon.jsii.Kernel.get(this, "denyAll", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.enforce = software.amazon.jsii.Kernel.get(this, "enforce", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.values = software.amazon.jsii.Kernel.get(this, "values", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowAll = builder.allowAll;
            this.condition = builder.condition;
            this.denyAll = builder.denyAll;
            this.enforce = builder.enforce;
            this.values = builder.values;
        }

        @Override
        public final java.lang.String getAllowAll() {
            return this.allowAll;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition getCondition() {
            return this.condition;
        }

        @Override
        public final java.lang.String getDenyAll() {
            return this.denyAll;
        }

        @Override
        public final java.lang.String getEnforce() {
            return this.enforce;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues getValues() {
            return this.values;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowAll() != null) {
                data.set("allowAll", om.valueToTree(this.getAllowAll()));
            }
            if (this.getCondition() != null) {
                data.set("condition", om.valueToTree(this.getCondition()));
            }
            if (this.getDenyAll() != null) {
                data.set("denyAll", om.valueToTree(this.getDenyAll()));
            }
            if (this.getEnforce() != null) {
                data.set("enforce", om.valueToTree(this.getEnforce()));
            }
            if (this.getValues() != null) {
                data.set("values", om.valueToTree(this.getValues()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.orgPolicyPolicy.OrgPolicyPolicyDryRunSpecRules"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OrgPolicyPolicyDryRunSpecRules.Jsii$Proxy that = (OrgPolicyPolicyDryRunSpecRules.Jsii$Proxy) o;

            if (this.allowAll != null ? !this.allowAll.equals(that.allowAll) : that.allowAll != null) return false;
            if (this.condition != null ? !this.condition.equals(that.condition) : that.condition != null) return false;
            if (this.denyAll != null ? !this.denyAll.equals(that.denyAll) : that.denyAll != null) return false;
            if (this.enforce != null ? !this.enforce.equals(that.enforce) : that.enforce != null) return false;
            return this.values != null ? this.values.equals(that.values) : that.values == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowAll != null ? this.allowAll.hashCode() : 0;
            result = 31 * result + (this.condition != null ? this.condition.hashCode() : 0);
            result = 31 * result + (this.denyAll != null ? this.denyAll.hashCode() : 0);
            result = 31 * result + (this.enforce != null ? this.enforce.hashCode() : 0);
            result = 31 * result + (this.values != null ? this.values.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/org_policy_policy/OrgPolicyPolicyDryRunSpecRules.java <==
package com.hashicorp.cdktf.providers.google.org_policy_policy;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:16.835Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.orgPolicyPolicy.OrgPolicyPolicyDryRunSpecRules")
@software.amazon.jsii.Jsii.Proxy(OrgPolicyPolicyDryRunSpecRules.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface OrgPolicyPolicyDryRunSpecRules extends software.amazon.jsii.JsiiSerializable {

    /**
     * Setting this to <code>"TRUE"</code> means that all values are allowed.
     * <p>
     * This field can be set only in policies for list constraints.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#allow_all OrgPolicyPolicy#allow_all}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getAllowAll() {
        return null;
    }

    /**
     * condition block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#condition OrgPolicyPolicy#condition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition getCondition() {
        return null;
    }

    /**
     * Setting this to <code>"TRUE"</code> means that all values are denied.
     * <p>
     * This field can be set only in policies for list constraints.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#deny_all OrgPolicyPolicy#deny_all}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDenyAll() {
        return null;
    }

    /**
     * If <code>"TRUE"</code>, then the policy is enforced.
     * <p>
     * If `"FALSE"`, then any configuration is acceptable. This field can be set only in policies for boolean constraints.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#enforce OrgPolicyPolicy#enforce}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getEnforce() {
        return null;
    }

    /**
     * values block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#values OrgPolicyPolicy#values}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues getValues() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link OrgPolicyPolicyDryRunSpecRules}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link OrgPolicyPolicyDryRunSpecRules}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<OrgPolicyPolicyDryRunSpecRules> {
        java.lang.String allowAll;
        com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition condition;
        java.lang.String denyAll;
        java.lang.String enforce;
        com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues values;

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getAllowAll}
         * @param allowAll Setting this to <code>"TRUE"</code> means that all values are allowed.
         *                 This field can be set only in policies for list constraints.
         *                 
         *                 Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#allow_all OrgPolicyPolicy#allow_all}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder allowAll(java.lang.String allowAll) {
            this.allowAll = allowAll;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getCondition}
         * @param condition condition block.
         *                  Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#condition OrgPolicyPolicy#condition}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder condition(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition condition) {
            this.condition = condition;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getDenyAll}
         * @param denyAll Setting this to <code>"TRUE"</code> means that all values are denied.
         *                This field can be set only in policies for list constraints.
         *                
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#deny_all OrgPolicyPolicy#deny_all}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder denyAll(java.lang.String denyAll) {
            this.denyAll = denyAll;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getEnforce}
         * @param enforce If <code>"TRUE"</code>, then the policy is enforced.
         *                If `"FALSE"`, then any configuration is acceptable. This field can be set only in policies for boolean constraints.
         *                
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#enforce OrgPolicyPolicy#enforce}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder enforce(java.lang.String enforce) {
            this.enforce = enforce;
            return this;
        }

        /**
         * Sets the value of {@link OrgPolicyPolicyDryRunSpecRules#getValues}
         * @param values values block.
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/org_policy_policy#values OrgPolicyPolicy#values}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder values(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues values) {
            this.values = values;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link OrgPolicyPolicyDryRunSpecRules}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public OrgPolicyPolicyDryRunSpecRules build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link OrgPolicyPolicyDryRunSpecRules}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements OrgPolicyPolicyDryRunSpecRules {
        private final java.lang.String allowAll;
        private final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition condition;
        private final java.lang.String denyAll;
        private final java.lang.String enforce;
        private final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues values;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.allowAll = software.amazon.jsii.Kernel.get(this, "allowAll", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.condition = software.amazon.jsii.Kernel.get(this, "condition", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition.class));
            this.denyAll = software.amazon.jsii.Kernel.get(this, "denyAll", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.enforce = software.amazon.jsii.Kernel.get(this, "enforce", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.values = software.amazon.jsii.Kernel.get(this, "values", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.allowAll = builder.allowAll;
            this.condition = builder.condition;
            this.denyAll = builder.denyAll;
            this.enforce = builder.enforce;
            this.values = builder.values;
        }

        @Override
        public final java.lang.String getAllowAll() {
            return this.allowAll;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesCondition getCondition() {
            return this.condition;
        }

        @Override
        public final java.lang.String getDenyAll() {
            return this.denyAll;
        }

        @Override
        public final java.lang.String getEnforce() {
            return this.enforce;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.org_policy_policy.OrgPolicyPolicyDryRunSpecRulesValues getValues() {
            return this.values;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAllowAll() != null) {
                data.set("allowAll", om.valueToTree(this.getAllowAll()));
            }
            if (this.getCondition() != null) {
                data.set("condition", om.valueToTree(this.getCondition()));
            }
            if (this.getDenyAll() != null) {
                data.set("denyAll", om.valueToTree(this.getDenyAll()));
            }
            if (this.getEnforce() != null) {
                data.set("enforce", om.valueToTree(this.getEnforce()));
            }
            if (this.getValues() != null) {
                data.set("values", om.valueToTree(this.getValues()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.orgPolicyPolicy.OrgPolicyPolicyDryRunSpecRules"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            OrgPolicyPolicyDryRunSpecRules.Jsii$Proxy that = (OrgPolicyPolicyDryRunSpecRules.Jsii$Proxy) o;

            if (this.allowAll != null ? !this.allowAll.equals(that.allowAll) : that.allowAll != null) return false;
            if (this.condition != null ? !this.condition.equals(that.condition) : that.condition != null) return false;
            if (this.denyAll != null ? !this.denyAll.equals(that.denyAll) : that.denyAll != null) return false;
            if (this.enforce != null ? !this.enforce.equals(that.enforce) : that.enforce != null) return false;
            return this.values != null ? this.values.equals(that.values) : that.values == null;
        }

        @Override
        public final int hashCode() {
            int result = this.allowAll != null ? this.allowAll.hashCode() : 0;
            result = 31 * result + (this.condition != null ? this.condition.hashCode() : 0);
            result = 31 * result + (this.denyAll != null ? this.denyAll.hashCode() : 0);
            result = 31 * result + (this.enforce != null ? this.enforce.hashCode() : 0);
            result = 31 * result + (this.values != null ? this.values.hashCode() : 0);
            return result;
        }
    }
}
